from Atom3d import Atom3d, ztox

SCWATERS = {
    'ARG': ((' NH1', ' CZ ', ' NE ', 2.8, 120.0, 180.0),
            (' NH1', ' CZ ', ' NE ', 2.8, 120.0,   0.0),
            (' NH2', ' CZ ', ' NE ', 2.8, 120.0, 180.0),
            (' NH2', ' CZ ', ' NE ', 2.8, 120.0,   0.0)
           ),
    'ASN': ((' OD1', ' CG ', ' CB ', 2.8, 120.0, 180.0),
            (' OD1', ' CG ', ' CB ', 2.8, 120.0,   0.0),
            (' ND2', ' CG ', ' CB ', 2.8, 120.0, 180.0),
            (' ND2', ' CG ', ' CB ', 2.8, 120.0,   0.0)
           ),
    'ASP': ((' OD1', ' CG ', ' CB ', 2.8, 120.0, 180.0),
            (' OD1', ' CG ', ' CB ', 2.8, 120.0,   0.0),
            (' OD2', ' CG ', ' CB ', 2.8, 120.0, 180.0),
            (' OD2', ' CG ', ' CB ', 2.8, 120.0,   0.0)
           ),
    'GLN': ((' OE1', ' CD ', ' CG ', 2.8, 120.0, 180.0),
            (' OE1', ' CD ', ' CG ', 2.8, 120.0,   0.0),
            (' NE2', ' CD ', ' CG ', 2.8, 120.0, 180.0),
            (' NE2', ' CD ', ' CG ', 2.8, 120.0,   0.0)
           ),
    'GLU': ((' OE1', ' CD ', ' CG ', 2.8, 120.0, 180.0),
            (' OE1', ' CD ', ' CG ', 2.8, 120.0,   0.0),
            (' OE2', ' CD ', ' CG ', 2.8, 120.0, 180.0),
            (' OE2', ' CD ', ' CG ', 2.8, 120.0,   0.0)
           ),
    'HIS': ((' ND1', ' CG ', ' CE1', 2.8, 120.0, 180.0),
            (' NE2', ' CD2', ' CE1', 2.8, 120.0, 180.0)
           ),
    'LYS': ((' NZ ', ' CE ', ' CD ', 2.8, 120.0, 180.0),
            (' NZ ', ' CE ', ' CD ', 2.8, 120.0,  60.0),
            (' NZ ', ' CE ', ' CD ', 2.8, 120.0, -60.0)
           ),
    'SER': ((' OG ', ' CB ', ' CA ', 2.8, 120.0, 180.0),
            (' OG ', ' CB ', ' CA ', 2.8, 120.0,  60.0),
            (' OG ', ' CB ', ' CA ', 2.8, 120.0, -60.0)
           ),
    'THR': ((' OG1', ' CB ', ' CA ', 2.8, 120.0, 180.0),
            (' OG1', ' CB ', ' CA ', 2.8, 120.0,  60.0),
            (' OG1', ' CB ', ' CA ', 2.8, 120.0, -60.0)
           ),
    'TYR': ((' OH ', ' CZ ', ' CE1', 2.8, 120.0, 180.0),
            (' OH ', ' CZ ', ' CE1', 2.8, 120.0,   0.0)
           ),
    'TRP': ((' NE1', ' CD1', ' CG ', 2.8, 111.58, 180.0),)
}
            
            

            


def make_water(fp, sp, tp, fpd=2.8, spa=120.0, tpt=180.0):
    w = Atom3d()
    w.first_parent = fp
    w.second_parent = sp
    w.third_parent = tp
    w.fp_distance = fpd
    w.sp_angle = spa
    w.tp_torsion = tpt
    w.radius = 1.35
    return w

def add_waters(p):
    waters = []
    for i in range(p.num_residues):
        rnam = p.residue_names[i]
        scatoms = SCWATERS.get(rnam, None)
        if scatoms is None:
            continue
        for fp, sp, tp, fpd, spa, tpt in scatoms:
            fp = p.get_atom(i, fp)
            sp = p.get_atom(i, sp)
            tp = p.get_atom(i, tp)
            waters.append(make_water(fp, sp, tp, fpd, spa, tpt))

##    atoms = p.atoms
##    rn = p.residue_names
##    fai = p.residue_first_atom_indices
##
##    # add backbone waters
##    for i in range(p.num_residues):
##        iN = fai[i]
##
##        # add carboxamide oxygen waters
##        ow1 = make_water(atoms[iN+3], atoms[iN+2], atoms[iN+1])
##        ow2 = make_water(atoms[iN+3], atoms[iN+2], ow1)
##        waters.append(ow1)
##        waters.append(ow2)
##
##        # add carboxamide nitrogen waters
##
##        resnam = rn[i]
##
##        if i > 0:
##            if resnam == 'PRO':
##                continue
##            waters.append(make_water(atoms[iN], atoms[iN+1], atoms[fai[i-1] + 2]))

    ztox(waters)
    p.waters = waters
        
        
