#! /usr/bin/env python

USAGE = """
        fasta2rib.py -i infile -o outfile

        where infile is the file containing the sequence in FASTA format. If
        not specified then stdin is assumed.  If the file has multiple
        sequences, only the first sequence is processed.

        outfile is the file to which the ribosome format file is to be
        written. If not specified stdout is assumed.
        """

import sys,os
import gzip
import string
from types import StringType

seq1to3 = {'A': 'ALA', 'C': 'CYS', 'D': 'ASP', 'E': 'GLU', 'F': 'PHE',
           'G': 'GLY', 'H': 'HIS', 'I': 'ILE', 'K': 'LYS', 'L': 'LEU',
           'M': 'MET', 'N': 'ASN', 'P': 'PRO', 'Q': 'GLN', 'R': 'ARG',
           'S': 'SER', 'T': 'THR', 'V': 'VAL', 'W': 'TRP', 'Y': 'TYR',
           'B': 'ASX', 'Z': 'GLX'}

def run(infile):

    file = open(infile,'r') 
    basename = os.path.basename(infile)
    prefix = os.path.splitext(basename)[0]

    while 1:
        line = file.readline()
        if not line:
            if file <> infile:
                file.close()

            raise IOError, 'File contains no sequences'

        if line[:1] == '>':
            name = string.strip(string.split(line[1:], None, 1)[0])
            break

    seq = []
    while 1:
        line = file.readline()
        if not line:
            break
        if line[:1] == '>':
            break
        seq.extend(string.split(line))

    file.close()
        
    seq = string.join(seq, '')

    outfile = open(prefix + '.rib', 'w')

    outfile.write('TITLE      %s\n' % name)
    outfile.write('DEFAULT PHI -120.0\n')
    outfile.write('DEFAULT PSI  120.0\n')


    for aa in seq:
        if aa == 'P':
            outfile.write('RES PRO PHI -70.0\n')
        else:
            outfile.write('RES %s\n' % seq1to3[aa])

    
    outfile.close()


if __name__ == "__main__":

    if len(sys.argv) < 2:
        print USAGE
        sys.exit()

    infile = sys.argv[1]

    run(infile) 
