#!/usr/bin/env python
"""Calulate all torsion angles and assign secondary structure and mesostate code"""

USAGE = """
python torsion.py pdbfile
Output is in file angles.dat
"""

import pdbparse
import prosst
import sys

def run(file):
    mol = pdbparse.read_pdb(file)
    mol.delete_hetero()
    fmt = "%5s %3s  %s %s %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f\n"
#   print mol.name
    angfile = open('angles.dat', 'w')
    for chain in mol:
        if chain.type() <> 'protein': continue
        chain.gaps()
        angfile.write('          SS MS    phi      psi     omega     chi1     chi2     chi3     chi4\n')
        phi, psi, ome, chi1, chi2, chi3, chi4 = chain.torsions()
        phi, psi, ome, ss = chain.pross(phi, psi, ome)
        pos = 0
        for res in chain.elements:
            ms = prosst.res_rc(phi[pos], psi[pos])
            angfile.write( fmt % (res.idx, res.name, ss[pos], ms, phi[pos], psi[pos], ome[pos],
                         chi1[pos], chi2[pos], chi3[pos], chi4[pos]))
            pos = pos + 1

    angfile.close()
if __name__ == "__main__":
    import sys
    import string

    if len(sys.argv) < 2:
        print USAGE
        sys.exit()

    for file in sys.argv[1:]:
        run(file)
