from Numeric import zeros, array, fromstring, LittleEndian
import marshal
import _gepol
import os

_triangle_cache = {
    1: None,
    2: None,
    3: None,
    4: None,
    5: None
}
import biomol
DATADIR = os.path.dirname(biomol.__file__)

def _gepol_load_triangles(ndiv):

    file = open(DATADIR + os.sep + 'gepol' +`ndiv` + '.dat', 'rb')
    triangles = fromstring(marshal.load(file), 'd')
    if LittleEndian:
        triangles = triangles.byteswapped()
    triangles.shape = (len(triangles)/3, 3)
    xc1 = array(triangles[:,0])
    yc1 = array(triangles[:,1])
    zc1 = array(triangles[:,2])
    del triangles
    return xc1, yc1, zc1    

def surface_and_volume(x, y, z, radius, probe_size=1.4, ndiv=3):
    if _triangle_cache[ndiv] is None:
        _triangle_cache[ndiv] = _gepol_load_triangles(ndiv)
    xc1, yc1, zc1 = _triangle_cache[ndiv]
    n = len(x)
    rad = radius + probe_size
    areas = zeros(n, 'd')
    s, v = _gepol.surf_vol(n, ndiv, x, y, z, rad, areas, xc1, yc1, zc1)
    del rad, xc1, yc1, zc1
    return s, v, areas


