#This module deals with .PMS files

import Numeric,string
from start_functions import open_file
from errors import not_open
from general import max_2dmat
import pylab,plots

#Entries in PMS files ordered by column
f2d = ['resnum','resi','*','A','B','C','D','E','F','G','H','I','J','K','L','M',
       'N','O','P','Q','R','S','T','U','V','W','X','g','h','i','j','k','l','m',
       'n','o','p','q','r'];

#Mesostate list according to order in mesostate comparison plots
ms_order = ['A','F','G','L','M','R','E','K','Q','J','P','O','I','D','C','B',
            'H','N','S','X','W','V','U','T','m','n','o','p','q','r','g','h',
            'i','j','k','l','*'];

class PMS:

    def __init__(self,fname,name=''):
        
        #Initialize elements
        self.info   = {};
        if name != '':
            self.name = name;
        else:
            self.name = string.split(fname,'.')[0];
        self.nres = -9999;
        
        #Initialize lists
        for i in xrange(len(f2d)):
            self.info[f2d[i]] = [];

        f = open_file(fname);
        if not_open(f,fname):
            raise '%s could not be opened.' %(fname)

        self.nres = len(f)-1;
        for i in xrange(len(f)):
            #Every 51 lines add a column of zeros for mesostates
            if i%50 == 1:
                for j in xrange(len(f2d)):
                    self.info[f2d[j]].append(0.0);

            #Don't include the first line
            if i == 0:
                continue
            
            #Read values into dictionary
            line = f[i].split();
            for j in xrange(len(line)):
                if j > 1:
                    self.info[f2d[j]].append(float(line[j]));
                else:
                    self.info[f2d[j]].append(line[j]);

        #Add extra zeros to make the number of columns divisible by 100
        for i in xrange(51 - len(self.info['A'])%51):
            for j in xrange(len(f2d)):
                self.info[f2d[j]].append(0.0);

        #Make float lists into Numeric arrays
        for j in xrange(len(f2d)):
            if j > 1:
                self.info[f2d[j]] = Numeric.array(self.info[f2d[j]]);

    #Print the line of data for a specific residue
    def line(self,n):
        s = '';
        for i in xrange(len(f2d)):
            s = s+str(self.info[f2d[i]][n+n/51]).rjust(6);
        return s

    #Make a matrix of all mesostate values for a plot
    def meso_mat(self):

        mat = [];
        #Make the first row in the matrix 0s for resi numbers
        mat.append(Numeric.array([0.0]*(len(self.info['A']))));
                                        
        for i in xrange(len(ms_order)):
            mat.append(self.info[ms_order[i]]);

        #Make the bottom left hand corner of each 38x50 matrix the largest
        #number so that all plots will be normalized relative to each other
        for i in xrange(len(mat[0])/51):
            mat[0][i*51] = max_2dmat(mat);
            
        return Numeric.array(mat);

    #Make plots to compare residues in different mesostates.
    #1 plot is made for every 50 residues.
    
    def plot_comp(self):

        #Make values into percentages
        mat = self.meso_mat()*100;

        #For every 50 residues,make a new plot,label it, and save it.
        #This is technically for every 51, but the first 'residue' in every
        #50 is blank to allow space to label mesostates
        for i in xrange(len(mat[0])/51):
            pylab.figure(figsize=(11,8.5));
            plots._pcolor(mat[:,51*i:51*(i+1)]);
            plots._label('Residue Number','Mesostates',self.name+' '+str(i+1));
            pylab.colorbar();
            plots.gridText(self.info['resnum'][51*i+1:51*(i+1)],1.5,0.5,1,
                           'x',4);
            plots.gridText(ms_order,0.5,1.5,1,'y',8);
            plots.xtickOff();
            plots.ytickOff();
            pylab.savefig(self.name+'_'+str(i+1)+'.ps',dpi=None, facecolor='w',
                          edgecolor='w',orientation='landscape');

        


        

        

        
