from rna_dic import *
from mol import *
import string, math

class RNA(Chain):

    def alpha(self, i):
        if i == 0:
            return 999.99
        
        res = self.elements[i]     

        try:
            a, b, c = res.atoms_with_name('P', 'O5*', 'C5*')
        except:
            return 999.99

        try:
            prev = self[i-1].atoms_with_name('O3*')[0]
        except IndexError:
            return 999.99
        else:
            return prev.torsion(a, b, c)

    def beta(self, i):
        atoms = self.elements[i].atoms_with_name('P', 'O5*', 'C5*', 'C4*')
        if len(atoms) <> 4:
            return 999.99
        else:
            a, b, c, d = atoms
            return a.torsion(b, c, d)

    def gamma(self, i):
        try:
            a, b, c, d = self.elements[i].atoms_with_name('O5*', 'C5*', 'C4*',
                                                          'C3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def delta(self, i):
        try:
            a, b, c, d = self.elements[i].atoms_with_name('C5*', 'C4*', 'C3*',
                                                          'O3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def epsilon(self, i):
        if i > len(self)-2:
            return 999.99

        res = self[i]

        try:
            a, b, c = res.atoms_with_name('C4*', 'C3*', 'O3*')
        except:
            return 999.99

        try:
            next = self[i+1].atoms_with_name('P')[0]
        except IndexError:
            return 999.99
        else:
            return a.torsion(b, c, next)

    def zeta(self, i):
        if i > len(self)-2:
            return 999.99

        res = self[i]

        try:
            a, b = res.atoms_with_name('C3*', 'O3*')
        except:
            return 999.99

        try:
            c, d = self[i+1].atoms_with_name('P', 'O5*')
        except:
            return 999.99

        return a.torsion(b, c, d)

    def nu0(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C4*', 'O4*', 'C1*', 'C2*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def nu1(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('O4*', 'C1*', 'C2*', 'C3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def nu2(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C1*', 'C2*', 'C3*', 'C4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def nu3(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C2*', 'C3*', 'C4*', 'O4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def nu4(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C3*', 'C4*', 'O4*', 'C1*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)
    def theta0(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C1*', 'C2*', 'C3*', 'C4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta1(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C2*', 'C3*', 'C4*', 'O4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta2(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C3*', 'C4*', 'O4*', 'C1*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta3(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('C4*', 'O4*', 'C1*', 'C2*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta4(self, i):
        try:
            a, b, c, d = self[i].atoms_with_name('O4*', 'C1*', 'C2*', 'C3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def phase(self, i):
        try:
            theta0 = self.theta0(i)
            theta1 = self.theta1(i)
            theta2 = self.theta2(i)
            theta3 = self.theta3(i)
            theta4 = self.theta4(i)
            
            numer = (theta2 + theta4) - (theta1 + theta3)
            denom = 2 * theta0 * (math.sin(36 * math.pi / 180) +
                                  math.sin(72 * math.pi / 180))
                    
            if denom == 0:
                return 999.99
            else:
                temp = math.atan(numer/denom) * 180 / math.pi
                
                if temp > 0:
                    if theta0 < 0:
                        temp = temp + 180
                else:
                    if theta4 < 0:
                        temp = temp + 360
                    else:
                        temp = temp + 180
                
                return temp
        
        except:
            return 999.99
            
    def amplitude(self, i):
        try:
            theta0 = self.theta0(i)
            theta1 = self.theta1(i)
            
            denom = math.cos(self.phase(i) * math.pi / 180)
            
            if denom == 0:
                denom = math.cos((self.phase(i) + 144) * math.pi /180)
                numer = theta1
                
            else:
                numer = theta0
                
            if denom is None or numer is None or denom == 0:
                return 999.99
            else:
                return numer/denom
                
        except:
            return 999.99
                
    def chi(self, i):
        res = self[i]
        atoms = CHI_ATOMS.get(res.name, None)
        if atoms is None:
            return 999.99
        else:
            try:
                a, b, c, d = apply(res.atoms_with_name, atoms)
            except:
                return 999.99
            else:
                return a.torsion(b, c, d)

    def torsions(self, i=None, map=map):
        if not i is None:
            return self.alpha(i), self.beta(i), self.gamma(i), \
                   self.delta(i), self.epsilon(i), self.zeta(i), \
                   self.chi(i), self.nu0(i), self.nu1(i), self.nu2(i),\
                   self.nu4(i), self.phase(i), self.amplitude(i)
        else:
            n = range(len(self))
            return map(self.alpha, n),\
                   map(self.beta, n),\
                   map(self.gamma, n),\
                   map(self.delta, n),\
                   map(self.epsilon, n),\
                   map(self.zeta, n),\
                   map(self.chi, n),\
                   map(self.nu0, n),\
                   map(self.nu1, n),\
                   map(self.nu2, n),\
                   map(self.nu3, n),\
                   map(self.nu4, n),\
                   map(self.phase, n),\
                   map(self.amplitude, n)


    def type(self):
        return 'rna'
            

class RNABase(Residue):

    def beta(self, i):
        atoms = self.atoms_with_name('P', 'O5*', 'C5*', 'C4*')
        if len(atoms) <> 4:
            return 999.99
        else:
            a, b, c, d = atoms
            return a.torsion(b, c, d)

    def gamma(self, i):
        try:
            a, b, c, d = self.atoms_with_name('O5*', 'C5*', 'C4*', 'C3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def delta(self, i):
        try:
            a, b, c, d = self.atoms_with_name('C5*', 'C4*', 'C3*', 'O3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def chi(self):
        atoms = CHI_ATOMS.get(self.name, None)
        if atoms is None:
            return 999.99
        else:
            try:
                a, b, c, d = apply(self.atoms_with_name, atoms)
            except:
                return 999.99
            else:
                return a.torsion(b, c, d)

    def theta0(self, i):
        try:
            a, b, c, d = self.atoms_with_name('C1*', 'C2*', 'C3*', 'C4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta1(self, i):
        try:
            a, b, c, d = self.atoms_with_name('C2*', 'C3*', 'C4*', 'O4*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta2(self, i):
        try:
            a, b, c, d = self.atoms_with_name('C3*', 'C4*', 'O4*', 'C1*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta3(self, i):
        try:
            a, b, c, d = self.atoms_with_name('C4*', 'O4*', 'C1*', 'C2*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def theta4(self, i):
        try:
            a, b, c, d = self.atoms_with_name('O4*', 'C1*', 'C2*', 'C3*')
        except:
            return 999.99
        else:
            return a.torsion(b, c, d)

    def phase(self, i):
        try:
            theta0 = self.theta0(i)
            theta1 = self.theta1(i)
            theta2 = self.theta2(i)
            theta3 = self.theta3(i)
            theta4 = self.theta4(i)
            
            numer = (theta2 + theta4) - (theta1 + theta3)
            denom = 2 * theta0 * (Numeric.sin(36 * Numeric.pi / 180)
                    + Numeric.sin(72 * Numeric.pi / 180))
                    
            if denom is None or numer is None or denom == 0:
                return 999.99
            else:
                temp = math.atan(numer/denom) * 180 / math.pi
                
                if temp > 0:
                    if theta0 < 0:
                        temp = temp + 180
                else:
                    if theta4 < 0:
                        temp = temp + 360
                    else:
                        temp = temp + 180
                
                return temp
        
        except:
            return 999.99
            
    def amplitude(self, i):
        try:
            theta0 = self.theta0(i)
            theta1 = self.theta1(i)
            
            denom = math.cos(self.phase(res) * math.pi / 180)
            
            if denom == 0:
                denom = math.cos((self.phase(res) + 144) * math.pi /180)
                numer = theta1
                
            else:
                numer = theta0
                
            if denom is None or numer is None or denom == 0:
                return 999.99
            else:
                return numer/denom
                
        except:
            return 999.99

    def type(self):
        return 'rna'

    def assign_radii(self):

        rad = SASARAD[self.name]
        
        for atom in self.elements:
            atom.radius = rad.get(atom.name, 0.0)






            



    

    
            
    
    
